pub struct RadixMapRepr<V, const KEY_BYTES: usize>where
V: Archive,
MissingOr<V>: Archive,{
pub entries: Vec<([u8; KEY_BYTES], MissingOr<V>)>,
}Fields
entries: Vec<([u8; KEY_BYTES], MissingOr<V>)>Trait Implementations
Sourceimpl<V, const KEY_BYTES: usize> Archive for RadixMapRepr<V, KEY_BYTES>
impl<V, const KEY_BYTES: usize> Archive for RadixMapRepr<V, KEY_BYTES>
Sourcetype Archived = ArchivedRadixMapRepr<V, KEY_BYTES>
type Archived = ArchivedRadixMapRepr<V, KEY_BYTES>
The archived representation of this type. Read more
Sourcetype Resolver = RadixMapReprResolver<V, KEY_BYTES>
type Resolver = RadixMapReprResolver<V, KEY_BYTES>
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl<__D: Fallible + ?Sized, V, const KEY_BYTES: usize> Deserialize<RadixMapRepr<V, KEY_BYTES>, __D> for Archived<RadixMapRepr<V, KEY_BYTES>>
impl<__D: Fallible + ?Sized, V, const KEY_BYTES: usize> Deserialize<RadixMapRepr<V, KEY_BYTES>, __D> for Archived<RadixMapRepr<V, KEY_BYTES>>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RadixMapRepr<V, KEY_BYTES>, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RadixMapRepr<V, KEY_BYTES>, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized, V, const KEY_BYTES: usize> Serialize<__S> for RadixMapRepr<V, KEY_BYTES>
impl<__S: Fallible + ?Sized, V, const KEY_BYTES: usize> Serialize<__S> for RadixMapRepr<V, KEY_BYTES>