pub enum RadixTerminal<V, const KEY_BYTES: usize> {
Leaf {
value: MissingOr<V>,
},
Empty,
DivergingLeaf {
other_key: [u8; KEY_BYTES],
other_value_root: [u8; 32],
},
}Expand description
The node q’s walk terminates on.
Variants
Leaf
Membership: a leaf whose key is the queried key, carrying its value.
Empty
Non-membership: q’s path reaches an empty subtree.
DivergingLeaf
Non-membership: q’s path reaches a leaf for a different key that
shares q’s consumed prefix.